@@ -29,10 +29,9 @@ from sqlalchemy.orm.collections import attribute_mapped_collection
 from datetime import datetime
 from sqlalchemy import *
 from sqlalchemy.orm import relation, comparable_property
-from sqlalchemy.orm.collections import attribute_mapped_collection
 from vertical import PolymorphicVerticalProperty, VerticalPropertyDictMixin
 
-from knowledge.model import metadata, DeclarativeBase, DBSession
+from knowledge.model import DBSession, DeclarativeBase
 
 
 class Fact(PolymorphicVerticalProperty, DeclarativeBase):
